NAME
Git::Libgit2 - Low-level FFI bindings to libgit2
VERSION
version 0.001
SYNOPSIS
use Git::Libgit2 qw( init_lib version check_rc );
init_lib();
printf "libgit2 %s\n", version();
# Direct FFI calls live in Git::Libgit2::FFI
use Git::Libgit2::FFI;
my $rc = Git::Libgit2::FFI::git_repository_open(\my $repo, '/path/to/.git');
check_rc $rc;
DESCRIPTION
Low-level FFI::Platypus bindings to the libgit2 C library, via Alien::Libgit2.
This module is intentionally close to the C surface. Use Git::Native for an idiomatic Moo wrapper with RAII handle management.
EXPORTS
init_lib, shutdown_lib, version, check_rc, oid_from_hex, oid_to_hex, plus object-type and repository-init constants.
SEE ALSO
Alien::Libgit2, Git::Native, FFI::Platypus, libgit2
SUPPORT
Issues
Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-git-libgit2/issues.
CONTRIBUTING
Contributions are welcome! Please fork the repository and submit a pull request.
AUTHOR
Torsten Raudssus <getty@cpan.org>
COPYRIGHT AND LICENSE
This software is copyright (c) 2026 by Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.